@@ -10,7 +10,7 @@ use base 'POD2::Base';
 use Encode::Locale qw(decode_argv);
 
 use 5.008_005;
-our $VERSION = '5.18.0.1.59';
+our $VERSION = '5.18.0.1.60';
 
 our @EXPORT_OK = qw(print_pod print_pods);
 
@@ -49,7 +49,7 @@ sub search_perlfunc_re {
 # Print information about a pod file
 sub print_pod {
     my ( $self, @tmp_args ) = @_;
-    my @args = @tmp_args ? @tmp_args : @ARGV;
+    my @args = @tmp_args;# ? @tmp_args : @ARGV;
     prepare_encoding_console();
     my $pods = $self->pod_info;
 
@@ -190,17 +190,11 @@ C<<pod_info>> - Выдает хэш с текущими pod файлами в д
 
 =head1 AUTHOR
  
-=over 4
- 
-=item *
- 
 Nikolay Mishin (L<MISHIN|https://metacpan.org/author/MISHIN>)
- 
-=back
 
 =head1 CONTRIBUTORS
 
-=over
+=over 1
 
 =item * Анатолий Шарифулин (L<SHARIFULN|https://metacpan.org/author/SHARIFULN>)
 
